Learn R Programming

distribglm (version 0.4.1)

aggregate_gradients: Aggregate Gradient values

Description

Aggregate Gradient values

Usage

aggregate_gradients(all_gradient_files, iteration_number)

Arguments

all_gradient_files

vector of character paths to files for gradients to combine together on the computing site

iteration_number

number of fitting iteration, used for tracking and checking

Value

A list of estimated values, including the gradient, sample size, iteration number, covariance matrix (A_mat), number of samples with non-zero weights, the sum of the dispersion values (for overdispersion estimates)