Aggregate Gradient values
aggregate_gradients(all_gradient_files, iteration_number)vector of character paths to files for gradients to combine together on the computing site
number of fitting iteration, used for tracking and checking
A list of estimated values, including the gradient,
sample size, iteration number, covariance matrix (A_mat),
number of samples with non-zero weights, the sum of the dispersion
values (for overdispersion estimates)